@@ -5,4 +5,6 @@ from .context import MetadataContext
 from .entity.dataset import Dataset
 from .entity.dataset_group import DatasetGroup
 from .entity.model import Model
-from .entity.model_group import ModelGroup
\ No newline at end of file
+from .entity.model_group import ModelGroup
+from .entity.workflow import Workflow
+from .entity.job import Job
