@@ -58,13 +58,15 @@ def get_main_parser(resources, action=None, target=None):
 
     subparsers = parser.add_subparsers(dest='action', help='Sub commands')
     login_parser = subparsers.add_parser('login', help='do login')
-    login_parser.add_argument('endpoint', type=str, help='metadata endpoint, http[s]://datahub.*.com')
+    login_parser.add_argument('endpoint', type=str, help='metadata endpoint, eg https://datahub-gms.dp.tech')
     login_parser.add_argument('-n', '--name', action='store', dest='name', type=str)
     login_parser.add_argument('--token', required=False)
     login_parser.add_argument('--project', required=False, default='default')
     login_parser.add_argument('--bohrium-user', required=False)
     login_parser.add_argument('--bohrium-password', required=False)
     login_parser.add_argument('--bohrium-project', required=False)
+    login_parser.add_argument('--bohrium-url', required=False)
+    login_parser.add_argument('--tiefblue-url', required=False)
 
     shell_parser = subparsers.add_parser('shell', help='do shell')
     shell_parser.add_argument('-c', '--command', action='store', type=str)
@@ -272,13 +274,13 @@ def _main():
     elif main_args.action == 'shell':
         if main_args.statement:
             from metadata.utils.ipython import do_eval
-            print(do_eval(main_args.statement, main_args.workspace))
+            print(do_eval(main_args.statement))
         elif main_args.command:
             from metadata.utils.ipython import do_exec
-            do_exec(main_args.command, main_args.workspace)
+            do_exec(main_args.command)
         else:
             from metadata.utils.ipython import main as ipython_main
-            ipython_main(main_args.workspace)
+            ipython_main()
     elif main_args.action in (
             'get', 'delete', 'create', 'update', 'edit', 'describe',
             'download', 'upload'):
