@@ -31,12 +31,14 @@ from .mixins.dataset import DatasetMixin
 from .mixins.dataset_group import DatasetGroupMixin
 from .mixins.model import ModelMixin
 from .mixins.model_group import ModelGroupMixin
+from .mixins.job import DataJobMixin
+from .mixins.workflow import WorkflowMixin
 
 logger = logging.getLogger(__name__)
 __all__ = ['Client']
 
 
-class Client(DatasetMixin, DatasetGroupMixin, ModelMixin, ModelGroupMixin):
+class Client(DatasetMixin, DatasetGroupMixin, ModelMixin, ModelGroupMixin, DataJobMixin, WorkflowMixin):
 
     def __init__(self, context: MetadataContext):
         self.context = context 
@@ -119,25 +121,20 @@ class Client(DatasetMixin, DatasetGroupMixin, ModelMixin, ModelGroupMixin):
     def upload_artifact(self, storage_prefix, path_prefix, source):
         storage_client = self.context.storage_client
         ensure_true(storage_client, 'Storage Client required for context')
-        prefix = storage_prefix or uuid.uuid4().hex
-        from dflow import s3_config
-        uri = os.path.join(s3_config["prefix"], prefix)
-        prefix = uri
+        prefix = os.path.join(storage_client.get_prefix(), storage_prefix or uuid.uuid4().hex)
         source = os.path.abspath(source)
         if os.path.isdir(source):
             files = [(i[len(source)+1:], i) for i in glob.glob(f'{source}/**/*', recursive=True) if not os.path.isdir(i)]
         else:
             files = [(os.path.basename(source), source)]
         
-        from dflow import upload_s3
         for suffix_key, file in files:
-            print(prefix, path_prefix, suffix_key)
             key = os.path.join(prefix, path_prefix or '', suffix_key)
-            print(file, key, prefix)
-            upload_s3(file, key=key, prefix=uri)
-        return uri
+            storage_client.upload(key=key, path=file)
+        return prefix
     
-    def delete_artifact(self, key):
+    def delete_artifact(self, storage_prefix):
         storage_client = self.context.storage_client
         ensure_true(storage_client, 'Storage Client required for context')
-        storage_client.delete
\ No newline at end of file
+        for key in storage_client.list(storage_prefix, recursive=True):
+            storage_client.delete(key)
\ No newline at end of file
