@@ -11,7 +11,7 @@ from datahub.metadata.schema_classes import DatasetPropertiesClass, ContainerCla
 
 from metadata.ensure import ensure_type, ensure_true
 from metadata.entity.dataset import Dataset
-
+from datahub.metadata.com.linkedin.pegasus2avro.dataset import DatasetLineageTypeClass, UpstreamClass, UpstreamLineage
 
 logger = logging.getLogger(__name__)
 
@@ -35,26 +35,6 @@ class DatasetMixin:
         self._emit_aspects(Dataset.entity_type, dataset.urn, filter(None, [dataset_properties, global_tags, owner_aspect, container_aspect]))
         return dataset.urn
 
-    def migrate_dataset(self,  dataset: Dataset, urn: str, upsert=True):
-        ensure_type(dataset, Dataset)
-
-        r = self._query_graphql(Dataset.entity_type, urn=urn)['data']['dataset']['editableDatasetProperties']
-
-        properties = copy.deepcopy(dataset.properties)
-        properties['uri'] = dataset.uri
-        dataset_properties = DatasetPropertiesClass(
-            name=dataset.display_name,
-            customProperties=properties,
-            description=dataset.description,
-        )
-        global_tags = self._get_tags_aspect(dataset.tags)
-        owner_aspect = self._get_ownership_aspect(dataset.owners or [self.context.user_email])
-        container_aspect = ContainerClass(
-            dataset.group
-        ) if dataset.group else None
-        self._emit_aspects(Dataset.entity_type, dataset.urn, filter(None, [dataset_properties, global_tags, owner_aspect, container_aspect]))
-        return dataset.urn
-
     def update_dataset(self, dataset: Dataset):
         return self.create_dataset(dataset, upsert=True)
 
@@ -62,7 +42,7 @@ class DatasetMixin:
         if not self.check_entity_exists(urn):
             return
         r = self._query_graphql(Dataset.entity_type, urn=urn)['data']['dataset']
-        properties = r['properties']
+        properties = r.get('properties', {})
         custom_properties = {e['key']: e['value'] for e in properties.get('customProperties', {})}
         display_name = properties.get('name', r.get('name'))
         uri = custom_properties.pop('uri', None)
@@ -74,13 +54,18 @@ class DatasetMixin:
             tags=tags,
             description=properties.get('description', r.get('description', '')),
             properties=custom_properties,
-            owners=[o['owner']['urn'].split(':', maxsplit=3)[-1] for o in r.get('ownership', {}).get('owners')],
+            owners=[o['owner']['urn'].split(':', maxsplit=3)[-1] for o in r.get('ownership', {}).get('owners', [])],
             group=r.get('container', {}).get('urn'),
         )
         return dataset
 
     def delete_dataset(self, urn: str, soft=True):
-        return self._delete_entity(urn, soft=soft)
+        dataset = self.get_dataset(urn)
+        if not dataset:
+            return
+        if not soft:
+            self.delete_artifact(dataset.uri)
+        self._delete_entity(urn, soft=soft)
     
     def get_datasets_by_facts(self, *, owner: str=None, group: str=None, tags: List[str]=None, search: str='', start=0, count=1000):
         facts = []
@@ -104,3 +89,13 @@ class DatasetMixin:
                 continue
             target = os.path.abspath(os.path.join(dest, rfile))
             storage_client.download(file, target)
+
+    def set_upstream(self, dataset: Dataset, upstream_list: List[Dataset]):
+        upstreams = []
+        for _dataset in upstream_list:
+            upstream_table = UpstreamClass(
+                dataset=_dataset.urn,
+                type=DatasetLineageTypeClass.TRANSFORMED)
+            upstreams.append(upstream_table)
+        upstream_lineage = UpstreamLineage(upstreams=upstreams)
+        self._emit_aspects(Dataset.entity_type, dataset.urn, upstream_lineage)
