@@ -36,7 +36,7 @@ class ModelGroupMixin:
         if not self.check_entity_exists(urn):
             return
         r = self._query_graphql(ModelGroup.entity_type, urn=urn)['data'][ModelGroup.entity_type]
-        properties = r['properties']
+        properties = r.get('properties', {})
         custom_properties = {e['key']: e['value'] for e in properties.get('customProperties', {})}
         display_name = custom_properties.pop('display_name', r['name'])
         tags = [t['tag']['urn'].split(':', maxsplit=3)[-1] for t in r.get('tags', {}).get('tags', [])]
@@ -45,7 +45,7 @@ class ModelGroupMixin:
             tags=tags,
             display_name=display_name,
             description=properties.get('description', r.get('description', '')),
-            owners=[o['owner']['urn'].split(':', maxsplit=3)[-1] for o in r.get('ownership', {}).get('owners')],
+            owners=[o['owner']['urn'].split(':', maxsplit=3)[-1] for o in r.get('ownership', {}).get('owners', [])],
             properties=custom_properties,
             created_at=properties.get('createdAt'),
             version=properties.get('version'),
