@@ -4,20 +4,23 @@ import os
 import copy
 import logging
 import contextlib
-import backoff
 from functools import partial, wraps, cached_property
 import urllib3
 import threading
-import requests
+from typing import Mapping, Any, Optional
 from urllib.parse import urljoin
 from http.client import HTTPConnection
 from urllib3.exceptions import InsecureRequestWarning
+
+import backoff
+import requests
 from requests.exceptions import ConnectionError
 from datahub.emitter.rest_emitter import DatahubRestEmitter                                                                                                                                                                            
 
 from metadata.exception import MetadataContextError
 from metadata.consts import ENV_TYPE
 from metadata.utils.url import build_url
+from metadata.utils.storage import StorageClient
 from metadata.ensure import (
     ensure_endpoint_format, ensure_token_format, 
     ensure_project_format, ensure_env_enum,
@@ -32,11 +35,11 @@ __all__ = ['MetadataContext', 'get_current_context']
 
 class MetadataContext(object):
 
-    def __init__(self, endpoint=None, token=None, *,
-            project='default',
+    def __init__(self, endpoint: Optional[str]=None, token: Optional[str]=None, *,
+            project: str='default',
             env=ENV_TYPE.CORP,
-            options=None,
-            storage_client=None):
+            options: Optional[Mapping[str, Any]]=None,
+            storage_client: Optional[StorageClient]=None):
 
         endpoint = endpoint or os.getenv('DATAHUB_GMS_URL')
         token = token or os.getenv('DATAHUB_GMS_TOKEN')
@@ -228,5 +231,6 @@ def get_current_context() -> MetadataContext:
                 contexts = [context]
                 setattr(local, 'contexts', contexts)
         except Exception as e:
+            raise
             logger.warn('found invalid context, take `metadata login` to refresh context, %s', e)
     return contexts[-1] if contexts else None
\ No newline at end of file
