@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 
+import jwt
 import sys
 import logging
 import validators
@@ -17,6 +18,10 @@ logger = logging.getLogger(__name__)
 
 
 def ensure_token_format(token):
+    try:
+        jwt.decode(token, verify=False, algorithms='HS256', options={"verify_signature": False})
+    except:
+        raise MetadataValueError('Token format error')
     return token
 
 def ensure_endpoint_format(endpoint):
